@@ -120,8 +120,27 @@ catalyze().  From inside a Squatting controller, these can be accessed via
 $self->v and $self->state.  Squatting controllers also get access to
 Catalyst's logging object via $self->log.
 
+In summary:
+
+  Catalyst                              Squatting
+  --------                              ---------
+  $c->stash                             $self->v
+  $c->session                           $self->state
+  $c->log                               $self->log
+
 =head1 SEE ALSO
 
 L<Catalyst>, L<Catalyst::Request>, L<Catalyst::Response>
 
 =cut
+
+# Local Variables: ***
+# mode: cperl ***
+# indent-tabs-mode: nil ***
+# cperl-close-paren-offset: -2 ***
+# cperl-continued-statement-offset: 2 ***
+# cperl-indent-level: 2 ***
+# cperl-indent-parens-as-block: t ***
+# cperl-tab-always-indent: nil ***
+# End: ***
+# vim:tabstop=8 softtabstop=2 shiftwidth=2 shiftround expandtab
